@@ -6,6 +6,6 @@ if ty.TYPE_CHECKING:
    import discord
 
 
-def perm_check(c: discord.TextChannel, need:discord.Permissions):
-   if not need <= (p := c.permissions_for(c.guild.me)):
+def perm_check(c: discord.TextChannel, need: discord.Permissions):
+   if not need >= (p := c.permissions_for(c.guild.me)):
       raise BotMissingPermissions(need, p)
